from rdflib import URIRef

# WARNING. This is a Generated File. Please do not edit.
# Please refer to the README at java/src/main/java/com/ncc/aif/ont2javagen for more information
# Last generated on: 08/24/2020 11:09:20
NAMESPACE = 'https://raw.githubusercontent.com/NextCenturyCorporation/AIDA-Interchange-Format/master/java/src/main/resources/com/ncc/aif/ontologies/EntityRelations#'

# Classes
Age = URIRef(NAMESPACE + 'Age')
Author = URIRef(NAMESPACE + 'Author')
Color = URIRef(NAMESPACE + 'Color')
Content = URIRef(NAMESPACE + 'Content')
Employment = URIRef(NAMESPACE + 'Employment')
Evaluate_Deliberateness_Accidental = URIRef(NAMESPACE + 'Evaluate.Deliberateness.Accidental')
Evaluate_Deliberateness_Deliberate = URIRef(NAMESPACE + 'Evaluate.Deliberateness.Deliberate')
Evaluate_Legitimacy_Illegitimate = URIRef(NAMESPACE + 'Evaluate.Legitimacy.Illegitimate')
Evaluate_Legitimacy_Legitimate = URIRef(NAMESPACE + 'Evaluate.Legitimacy.Legitimate')
Evaluate_Sentiment_Negative = URIRef(NAMESPACE + 'Evaluate.Sentiment.Negative')
Evaluate_Sentiment_Positive = URIRef(NAMESPACE + 'Evaluate.Sentiment.Positive')
Evaluation = URIRef(NAMESPACE + 'Evaluation')
Function = URIRef(NAMESPACE + 'Function')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation_ControlTerritory = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation.ControlTerritory')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation_NationalityCitizen = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation.NationalityCitizen')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation_OwnershipPossession = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation.OwnershipPossession')
GeneralAffiliation_MemberOriginReligionEthnicity = URIRef(NAMESPACE + 'GeneralAffiliation.MemberOriginReligionEthnicity')
GeneralAffiliation_MemberOriginReligionEthnicity_Ethnicity = URIRef(NAMESPACE + 'GeneralAffiliation.MemberOriginReligionEthnicity.Ethnicity')
GeneralAffiliation_MemberOriginReligionEthnicity_NationalityCitizen = URIRef(NAMESPACE + 'GeneralAffiliation.MemberOriginReligionEthnicity.NationalityCitizen')
GeneralAffiliation_OrganizationPoliticalReligiousAffiliation = URIRef(NAMESPACE + 'GeneralAffiliation.OrganizationPoliticalReligiousAffiliation')
GeneralAffiliation_OrganizationPoliticalReligiousAffiliation_NationalityCitizen = URIRef(NAMESPACE + 'GeneralAffiliation.OrganizationPoliticalReligiousAffiliation.NationalityCitizen')
GeneralAffiliation_OrganizationWebsite_OrganizationWebsite = URIRef(NAMESPACE + 'GeneralAffiliation.OrganizationWebsite.OrganizationWebsite')
GeneralAffiliation_Sponsorship = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship')
GeneralAffiliation_Sponsorship_AdvisePlanOrganize = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship.AdvisePlanOrganize')
GeneralAffiliation_Sponsorship_Affiliated = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship.Affiliated')
GeneralAffiliation_Sponsorship_HelpSupport = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship.HelpSupport')
Information_Color_Color = URIRef(NAMESPACE + 'Information.Color.Color')
Information_Make_Make = URIRef(NAMESPACE + 'Information.Make.Make')
LocRel = URIRef(NAMESPACE + 'LocRel')
Make = URIRef(NAMESPACE + 'Make')
Material = URIRef(NAMESPACE + 'Material')
Measurement_Size = URIRef(NAMESPACE + 'Measurement.Size')
Measurement_Size_Count = URIRef(NAMESPACE + 'Measurement.Size.Count')
Measurement_Size_HeightLengthWidth = URIRef(NAMESPACE + 'Measurement.Size.HeightLengthWidth')
Measurement_Size_Percentage = URIRef(NAMESPACE + 'Measurement.Size.Percentage')
Measurement_Size_Weight = URIRef(NAMESPACE + 'Measurement.Size.Weight')
Medium = URIRef(NAMESPACE + 'Medium')
Nationality = URIRef(NAMESPACE + 'Nationality')
OrganizationAffiliation_EmploymentMembership = URIRef(NAMESPACE + 'OrganizationAffiliation.EmploymentMembership')
OrganizationAffiliation_EmploymentMembership_Employment = URIRef(NAMESPACE + 'OrganizationAffiliation.EmploymentMembership.Employment')
OrganizationAffiliation_EmploymentMembership_Membership = URIRef(NAMESPACE + 'OrganizationAffiliation.EmploymentMembership.Membership')
OrganizationAffiliation_Founder_Founder = URIRef(NAMESPACE + 'OrganizationAffiliation.Founder.Founder')
OrganizationAffiliation_Leadership = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership')
OrganizationAffiliation_Leadership_Government = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership.Government')
OrganizationAffiliation_Leadership_HeadOfState = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership.HeadOfState')
OrganizationAffiliation_Leadership_MilitaryPolice = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership.MilitaryPolice')
PartWhole_Subsidiary = URIRef(NAMESPACE + 'PartWhole.Subsidiary')
PartWhole_Subsidiary_NationalityCitizen = URIRef(NAMESPACE + 'PartWhole.Subsidiary.NationalityCitizen')
PartWhole_Subsidiary_OrganizationSubsidiary = URIRef(NAMESPACE + 'PartWhole.Subsidiary.OrganizationSubsidiary')
PersonalSocial_Role = URIRef(NAMESPACE + 'PersonalSocial.Role')
PersonalSocial_Role_ProfessionalRole = URIRef(NAMESPACE + 'PersonalSocial.Role.ProfessionalRole')
PersonalSocial_Role_TitleFormOfAddress = URIRef(NAMESPACE + 'PersonalSocial.Role.TitleFormOfAddress')
PersonalSocial_Unspecified = URIRef(NAMESPACE + 'PersonalSocial.Unspecified')
PersonalSocial_Unspecified_Political = URIRef(NAMESPACE + 'PersonalSocial.Unspecified.Political')
Physical_LocatedNear = URIRef(NAMESPACE + 'Physical.LocatedNear')
Physical_LocatedNear_Surround = URIRef(NAMESPACE + 'Physical.LocatedNear.Surround')
Physical_OrganizationHeadquarters_OrganizationHeadquarters = URIRef(NAMESPACE + 'Physical.OrganizationHeadquarters.OrganizationHeadquarters')
Physical_Resident_Resident = URIRef(NAMESPACE + 'Physical.Resident.Resident')
ResponsibilityBlame_AssignBlame_AssignBlame = URIRef(NAMESPACE + 'ResponsibilityBlame.AssignBlame.AssignBlame')
ResponsibilityBlame_ClaimResponsibility_ClaimResponsibility = URIRef(NAMESPACE + 'ResponsibilityBlame.ClaimResponsibility.ClaimResponsibility')
Side = URIRef(NAMESPACE + 'Side')
Size = URIRef(NAMESPACE + 'Size')
Status = URIRef(NAMESPACE + 'Status')
Structure = URIRef(NAMESPACE + 'Structure')
Title = URIRef(NAMESPACE + 'Title')

# Properties
Age_Object = URIRef(NAMESPACE + 'Age_Object')
Age_Subject = URIRef(NAMESPACE + 'Age_Subject')
Author_Object = URIRef(NAMESPACE + 'Author_Object')
Author_Subject = URIRef(NAMESPACE + 'Author_Subject')
Color_Object = URIRef(NAMESPACE + 'Color_Object')
Color_Subject = URIRef(NAMESPACE + 'Color_Subject')
Content_Object = URIRef(NAMESPACE + 'Content_Object')
Content_Subject = URIRef(NAMESPACE + 'Content_Subject')
Employment_Object = URIRef(NAMESPACE + 'Employment_Object')
Employment_Subject = URIRef(NAMESPACE + 'Employment_Subject')
Evaluate_Deliberateness_Accidental_Event = URIRef(NAMESPACE + 'Evaluate.Deliberateness.Accidental_Event')
Evaluate_Deliberateness_Accidental_Holder = URIRef(NAMESPACE + 'Evaluate.Deliberateness.Accidental_Holder')
Evaluate_Deliberateness_Deliberate_Event = URIRef(NAMESPACE + 'Evaluate.Deliberateness.Deliberate_Event')
Evaluate_Deliberateness_Deliberate_Holder = URIRef(NAMESPACE + 'Evaluate.Deliberateness.Deliberate_Holder')
Evaluate_Legitimacy_Illegitimate_Event = URIRef(NAMESPACE + 'Evaluate.Legitimacy.Illegitimate_Event')
Evaluate_Legitimacy_Illegitimate_Holder = URIRef(NAMESPACE + 'Evaluate.Legitimacy.Illegitimate_Holder')
Evaluate_Legitimacy_Legitimate_Event = URIRef(NAMESPACE + 'Evaluate.Legitimacy.Legitimate_Event')
Evaluate_Legitimacy_Legitimate_Holder = URIRef(NAMESPACE + 'Evaluate.Legitimacy.Legitimate_Holder')
Evaluate_Sentiment_Negative_Holder = URIRef(NAMESPACE + 'Evaluate.Sentiment.Negative_Holder')
Evaluate_Sentiment_Negative_SentimentTarget = URIRef(NAMESPACE + 'Evaluate.Sentiment.Negative_SentimentTarget')
Evaluate_Sentiment_Positive_Holder = URIRef(NAMESPACE + 'Evaluate.Sentiment.Positive_Holder')
Evaluate_Sentiment_Positive_SentimentTarget = URIRef(NAMESPACE + 'Evaluate.Sentiment.Positive_SentimentTarget')
Evaluation_Object = URIRef(NAMESPACE + 'Evaluation_Object')
Evaluation_Subject = URIRef(NAMESPACE + 'Evaluation_Subject')
Function_Object = URIRef(NAMESPACE + 'Function_Object')
Function_Subject = URIRef(NAMESPACE + 'Function_Subject')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation_Artifact = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation_Artifact')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation_ControlTerritory_Controller = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation.ControlTerritory_Controller')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation_ControlTerritory_Territory = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation.ControlTerritory_Territory')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation_EntityOrFiller = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation_EntityOrFiller')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation_NationalityCitizen_Artifact = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation.NationalityCitizen_Artifact')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation_NationalityCitizen_Nationality = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation.NationalityCitizen_Nationality')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation_OwnershipPossession_Artifact = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation.OwnershipPossession_Artifact')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation_OwnershipPossession_Owner = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation.OwnershipPossession_Owner')
GeneralAffiliation_MemberOriginReligionEthnicity_EntityOrFiller = URIRef(NAMESPACE + 'GeneralAffiliation.MemberOriginReligionEthnicity_EntityOrFiller')
GeneralAffiliation_MemberOriginReligionEthnicity_Ethnicity_Ethnicity = URIRef(NAMESPACE + 'GeneralAffiliation.MemberOriginReligionEthnicity.Ethnicity_Ethnicity')
GeneralAffiliation_MemberOriginReligionEthnicity_Ethnicity_Person = URIRef(NAMESPACE + 'GeneralAffiliation.MemberOriginReligionEthnicity.Ethnicity_Person')
GeneralAffiliation_MemberOriginReligionEthnicity_NationalityCitizen_Citizen = URIRef(NAMESPACE + 'GeneralAffiliation.MemberOriginReligionEthnicity.NationalityCitizen_Citizen')
GeneralAffiliation_MemberOriginReligionEthnicity_NationalityCitizen_Nationality = URIRef(NAMESPACE + 'GeneralAffiliation.MemberOriginReligionEthnicity.NationalityCitizen_Nationality')
GeneralAffiliation_MemberOriginReligionEthnicity_Person = URIRef(NAMESPACE + 'GeneralAffiliation.MemberOriginReligionEthnicity_Person')
GeneralAffiliation_OrganizationPoliticalReligiousAffiliation_EntityOrFiller = URIRef(NAMESPACE + 'GeneralAffiliation.OrganizationPoliticalReligiousAffiliation_EntityOrFiller')
GeneralAffiliation_OrganizationPoliticalReligiousAffiliation_NationalityCitizen_Nationality = URIRef(NAMESPACE + 'GeneralAffiliation.OrganizationPoliticalReligiousAffiliation.NationalityCitizen_Nationality')
GeneralAffiliation_OrganizationPoliticalReligiousAffiliation_NationalityCitizen_Organization = URIRef(NAMESPACE + 'GeneralAffiliation.OrganizationPoliticalReligiousAffiliation.NationalityCitizen_Organization')
GeneralAffiliation_OrganizationPoliticalReligiousAffiliation_Organization = URIRef(NAMESPACE + 'GeneralAffiliation.OrganizationPoliticalReligiousAffiliation_Organization')
GeneralAffiliation_OrganizationWebsite_OrganizationWebsite_Organization = URIRef(NAMESPACE + 'GeneralAffiliation.OrganizationWebsite.OrganizationWebsite_Organization')
GeneralAffiliation_OrganizationWebsite_OrganizationWebsite_Website = URIRef(NAMESPACE + 'GeneralAffiliation.OrganizationWebsite.OrganizationWebsite_Website')
GeneralAffiliation_Sponsorship_ActorOrEvent = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship_ActorOrEvent')
GeneralAffiliation_Sponsorship_AdvisePlanOrganize_ActorOrEvent = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship.AdvisePlanOrganize_ActorOrEvent')
GeneralAffiliation_Sponsorship_AdvisePlanOrganize_Sponsor = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship.AdvisePlanOrganize_Sponsor')
GeneralAffiliation_Sponsorship_Affiliated_ActorOrEvent = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship.Affiliated_ActorOrEvent')
GeneralAffiliation_Sponsorship_Affiliated_Sponsor = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship.Affiliated_Sponsor')
GeneralAffiliation_Sponsorship_HelpSupport_ActorOrEvent = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship.HelpSupport_ActorOrEvent')
GeneralAffiliation_Sponsorship_HelpSupport_Sponsor = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship.HelpSupport_Sponsor')
GeneralAffiliation_Sponsorship_Sponsor = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship_Sponsor')
Information_Color_Color_Color = URIRef(NAMESPACE + 'Information.Color.Color_Color')
Information_Color_Color_EntityOrFiller = URIRef(NAMESPACE + 'Information.Color.Color_EntityOrFiller')
Information_Make_Make_Brand = URIRef(NAMESPACE + 'Information.Make.Make_Brand')
Information_Make_Make_EntityOrFiller = URIRef(NAMESPACE + 'Information.Make.Make_EntityOrFiller')
LocRel_Object = URIRef(NAMESPACE + 'LocRel_Object')
LocRel_Subject = URIRef(NAMESPACE + 'LocRel_Subject')
Make_Object = URIRef(NAMESPACE + 'Make_Object')
Make_Subject = URIRef(NAMESPACE + 'Make_Subject')
Material_Object = URIRef(NAMESPACE + 'Material_Object')
Material_Subject = URIRef(NAMESPACE + 'Material_Subject')
Measurement_Size_Count_EntityOrFiller = URIRef(NAMESPACE + 'Measurement.Size.Count_EntityOrFiller')
Measurement_Size_Count_Measurement = URIRef(NAMESPACE + 'Measurement.Size.Count_Measurement')
Measurement_Size_EntityOrFiller = URIRef(NAMESPACE + 'Measurement.Size_EntityOrFiller')
Measurement_Size_HeightLengthWidth_EntityOrFiller = URIRef(NAMESPACE + 'Measurement.Size.HeightLengthWidth_EntityOrFiller')
Measurement_Size_HeightLengthWidth_Measurement = URIRef(NAMESPACE + 'Measurement.Size.HeightLengthWidth_Measurement')
Measurement_Size_Measurement = URIRef(NAMESPACE + 'Measurement.Size_Measurement')
Measurement_Size_Percentage_EntityOrFiller = URIRef(NAMESPACE + 'Measurement.Size.Percentage_EntityOrFiller')
Measurement_Size_Percentage_Measurement = URIRef(NAMESPACE + 'Measurement.Size.Percentage_Measurement')
Measurement_Size_Weight_EntityOrFiller = URIRef(NAMESPACE + 'Measurement.Size.Weight_EntityOrFiller')
Measurement_Size_Weight_Measurement = URIRef(NAMESPACE + 'Measurement.Size.Weight_Measurement')
Medium_Object = URIRef(NAMESPACE + 'Medium_Object')
Medium_Subject = URIRef(NAMESPACE + 'Medium_Subject')
Nationality_Object = URIRef(NAMESPACE + 'Nationality_Object')
Nationality_Subject = URIRef(NAMESPACE + 'Nationality_Subject')
OrganizationAffiliation_EmploymentMembership_EmployeeMember = URIRef(NAMESPACE + 'OrganizationAffiliation.EmploymentMembership_EmployeeMember')
OrganizationAffiliation_EmploymentMembership_Employment_Employee = URIRef(NAMESPACE + 'OrganizationAffiliation.EmploymentMembership.Employment_Employee')
OrganizationAffiliation_EmploymentMembership_Employment_PlaceOfEmployment = URIRef(NAMESPACE + 'OrganizationAffiliation.EmploymentMembership.Employment_PlaceOfEmployment')
OrganizationAffiliation_EmploymentMembership_Membership_Member = URIRef(NAMESPACE + 'OrganizationAffiliation.EmploymentMembership.Membership_Member')
OrganizationAffiliation_EmploymentMembership_Membership_PlaceOfMembership = URIRef(NAMESPACE + 'OrganizationAffiliation.EmploymentMembership.Membership_PlaceOfMembership')
OrganizationAffiliation_EmploymentMembership_PlaceOfEmploymentMembership = URIRef(NAMESPACE + 'OrganizationAffiliation.EmploymentMembership_PlaceOfEmploymentMembership')
OrganizationAffiliation_Founder_Founder_Founder = URIRef(NAMESPACE + 'OrganizationAffiliation.Founder.Founder_Founder')
OrganizationAffiliation_Founder_Founder_Organization = URIRef(NAMESPACE + 'OrganizationAffiliation.Founder.Founder_Organization')
OrganizationAffiliation_Leadership_Government_GovernmentBodyOrGPE = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership.Government_GovernmentBodyOrGPE')
OrganizationAffiliation_Leadership_Government_Leader = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership.Government_Leader')
OrganizationAffiliation_Leadership_HeadOfState_Country = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership.HeadOfState_Country')
OrganizationAffiliation_Leadership_HeadOfState_Leader = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership.HeadOfState_Leader')
OrganizationAffiliation_Leadership_Leader = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership_Leader')
OrganizationAffiliation_Leadership_MilitaryPolice_Leader = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership.MilitaryPolice_Leader')
OrganizationAffiliation_Leadership_MilitaryPolice_MilitaryPoliceORG = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership.MilitaryPolice_MilitaryPoliceORG')
OrganizationAffiliation_Leadership_Organization = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership_Organization')
PartWhole_Subsidiary_NationalityCitizen_Parent = URIRef(NAMESPACE + 'PartWhole.Subsidiary.NationalityCitizen_Parent')
PartWhole_Subsidiary_NationalityCitizen_Subsidiary = URIRef(NAMESPACE + 'PartWhole.Subsidiary.NationalityCitizen_Subsidiary')
PartWhole_Subsidiary_OrganizationSubsidiary_Parent = URIRef(NAMESPACE + 'PartWhole.Subsidiary.OrganizationSubsidiary_Parent')
PartWhole_Subsidiary_OrganizationSubsidiary_Subsidiary = URIRef(NAMESPACE + 'PartWhole.Subsidiary.OrganizationSubsidiary_Subsidiary')
PartWhole_Subsidiary_Parent = URIRef(NAMESPACE + 'PartWhole.Subsidiary_Parent')
PartWhole_Subsidiary_Subsidiary = URIRef(NAMESPACE + 'PartWhole.Subsidiary_Subsidiary')
PersonalSocial_Role_Person = URIRef(NAMESPACE + 'PersonalSocial.Role_Person')
PersonalSocial_Role_ProfessionalRole_JobRole = URIRef(NAMESPACE + 'PersonalSocial.Role.ProfessionalRole_JobRole')
PersonalSocial_Role_ProfessionalRole_Person = URIRef(NAMESPACE + 'PersonalSocial.Role.ProfessionalRole_Person')
PersonalSocial_Role_Role = URIRef(NAMESPACE + 'PersonalSocial.Role_Role')
PersonalSocial_Role_TitleFormOfAddress_Person = URIRef(NAMESPACE + 'PersonalSocial.Role.TitleFormOfAddress_Person')
PersonalSocial_Role_TitleFormOfAddress_Title = URIRef(NAMESPACE + 'PersonalSocial.Role.TitleFormOfAddress_Title')
PersonalSocial_Unspecified_Person = URIRef(NAMESPACE + 'PersonalSocial.Unspecified_Person')
PersonalSocial_Unspecified_Political_Person = URIRef(NAMESPACE + 'PersonalSocial.Unspecified.Political_Person')
Physical_LocatedNear_EntityOrFiller = URIRef(NAMESPACE + 'Physical.LocatedNear_EntityOrFiller')
Physical_LocatedNear_Place = URIRef(NAMESPACE + 'Physical.LocatedNear_Place')
Physical_LocatedNear_Surround_EntityOrFiller = URIRef(NAMESPACE + 'Physical.LocatedNear.Surround_EntityOrFiller')
Physical_LocatedNear_Surround_Place = URIRef(NAMESPACE + 'Physical.LocatedNear.Surround_Place')
Physical_OrganizationHeadquarters_OrganizationHeadquarters_Organization = URIRef(NAMESPACE + 'Physical.OrganizationHeadquarters.OrganizationHeadquarters_Organization')
Physical_OrganizationHeadquarters_OrganizationHeadquarters_Place = URIRef(NAMESPACE + 'Physical.OrganizationHeadquarters.OrganizationHeadquarters_Place')
Physical_Resident_Resident_Place = URIRef(NAMESPACE + 'Physical.Resident.Resident_Place')
Physical_Resident_Resident_Resident = URIRef(NAMESPACE + 'Physical.Resident.Resident_Resident')
ResponsibilityBlame_AssignBlame_AssignBlame_EntityResponsible = URIRef(NAMESPACE + 'ResponsibilityBlame.AssignBlame.AssignBlame_EntityResponsible')
ResponsibilityBlame_AssignBlame_AssignBlame_Event = URIRef(NAMESPACE + 'ResponsibilityBlame.AssignBlame.AssignBlame_Event')
ResponsibilityBlame_ClaimResponsibility_ClaimResponsibility_EntityResponsible = URIRef(NAMESPACE + 'ResponsibilityBlame.ClaimResponsibility.ClaimResponsibility_EntityResponsible')
ResponsibilityBlame_ClaimResponsibility_ClaimResponsibility_Event = URIRef(NAMESPACE + 'ResponsibilityBlame.ClaimResponsibility.ClaimResponsibility_Event')
Side_Object = URIRef(NAMESPACE + 'Side_Object')
Side_Subject = URIRef(NAMESPACE + 'Side_Subject')
Size_Object = URIRef(NAMESPACE + 'Size_Object')
Size_Subject = URIRef(NAMESPACE + 'Size_Subject')
Status_Object = URIRef(NAMESPACE + 'Status_Object')
Status_Subject = URIRef(NAMESPACE + 'Status_Subject')
Structure_Object = URIRef(NAMESPACE + 'Structure_Object')
Structure_Subject = URIRef(NAMESPACE + 'Structure_Subject')
Title_Object = URIRef(NAMESPACE + 'Title_Object')
Title_Subject = URIRef(NAMESPACE + 'Title_Subject')



import json

from rdflib import RDF, XSD, BNode, Graph, Literal, URIRef
from rdflib.plugins.sparql import prepareQuery

from aida_interchange.rdf_ontologies import interchange_ontology


"""
A convenient interface for creating simple AIF graphs.

More complicated graphs will require direct manipulation of the RDF
"""


def make_graph():
    """
    Creates the underlying RDF model

    :returns: The RDF model
    :rtype: rdflib.graph.Graph
    """
    g = Graph()
    g.bind('aida', interchange_ontology.NAMESPACE)
    return g


def make_system_with_uri(graph, system_uri):
    """
    Create a resource representing the system which produced some data.

    Such a resource should be attached to all entities, events, event arguments, relations,
    sentiment assertions, confidences, justifications, etc. produced by a system. You should
    only create the system resource once; reuse the returned objects for all calls
    to [mark_system].

    :param rdflib.graph.Graph graph: The underlying RDF model
    :param str system_uri: A string URI representation of the system
    :returns: The created system resource
    :rtype: rdflib.term.URIRef

    """
    system = URIRef(system_uri)
    graph.add((system, RDF.type, interchange_ontology.System))
    return system


def mark_system(g, to_mark_on, system):
    """
    Mark a resource as coming from the specified [system]

    :param rdflib.graph.Graph g: The underlying RDF model
    :param rdflib.term.BNode to_mark_on: The resource to mark as coming from the specified system
    :param rdflib.term.URIRef system: The system with which to mark the specified resource
    """
    g.add((to_mark_on, interchange_ontology.system, system))


def mark_name(g, entity, name):
    """
    Mark [entity] as having the specified [name].

    :param rdflib.graph.Graph g: The underlying RDF model
    :param rdflib.term.URIRef entity: The resource to mark on
    :param str name: The string name with which to mark the specified resource
    """
    g.add((entity, interchange_ontology.hasName,
           Literal(name, datatype=XSD.string)))


def mark_text_value(g, entity, text_value):
    """
    Mark [entity] as having the specified [text_value].

    :param rdflib.graph.Graph g: The underlying RDF model
    :param rdflib.term.URIRef entity: The resource to mark as having the specified text value
    :param str text_value: The string text value with which to mark the specified resource
    """
    g.add((entity, interchange_ontology.textValue,
           Literal(text_value, datatype=XSD.string)))


def mark_numeric_value_as_string(g, entity, numeric_value):
    """
    Mark [entity] as having the specified [numeric_value] as string.

    :param rdflib.graph.Graph g: The underlying RDF model
    :param rdflib.term.URIRef entity: The resource to mark as having the specified numeric value
    :param str numeric_value: A string representation of a numeric value with which to
         mark the specified resource
    """
    g.add((entity, interchange_ontology.numericValue,
           Literal(numeric_value, datatype=XSD.string)))


def mark_numeric_value_as_double(g, entity, numeric_value):
    """
    Mark [entity] as having the specified [numeric_value] as double floating point.

    :param rdflib.graph.Graph g: The underlying RDF model
    :param rdflib.term.URIRef entity: The Resource to mark as having the specified numeric value
    :param str numeric_value: A double representation of a numeric value with which to mark the
        specified resource
    """
    g.add((entity, interchange_ontology.numericValue,
           Literal(numeric_value, datatype=XSD.double)))


def mark_numeric_value_as_long(g, entity, numeric_value):
    """
    Mark [entity] as having the specified [numeric_value] as long integer.

    :param rdflib.graph.Graph g: The underlying RDF model
    :param rdflib.term.URIRef entity: The resource to mark as having the specified numeric value
    :param str numeric_value: A long representation of a numeric value with which to mark the
        specified resource
    """
    g.add((entity, interchange_ontology.numericValue,
           Literal(numeric_value, datatype=XSD.long)))


def make_entity(g, entity_uri, system):
    """
    Create an entity.

    :param rdflib.graph.Graph g: The underlying RDF model
    :param rdflib.term.URIRef entity_uri: A unique string representing the uri. This can be any unique string.
    :param rdflib.term.URIRef system: The system object for the system which created this entity.
    :returns: The created entity resource
    :rtype: rdflib.term.URIRef
    """
    return _make_aif_resource(g, entity_uri, interchange_ontology.Entity, system)


def mark_type(g, type_assertion_uri, entity_or_event, _type, system, confidence):
    """
    Mark an entity, event, or relation as having a specified type.

    This is marked with a separate assertion so that uncertainty about type can be expressed.
    In such a case, bundle together the type assertion resources returned by this method with
    [mark_as_mutually_exclusive].

    :param rdflib.graph.Graph g: The underlying RDF model
    :param rdflib.term.URIRef type_assertion_uri: The string URI of a type assertion
        resource with which to mark the entity or event
    :param rdflib.term.URIRef entity_or_event: The entity, event, or relation to mark
        as having the specified type
    :param rdflib.term.URIRef _type: The type of the entity, event, or relation being asserted
    :param rdflib.term.URIRef system: The system object for the system which created this entity
    :param float confidence: If not None, the confidence with which to mark the specified type
    :returns: The created type assertion resource
    :rtype: rdflib.term.URIRef
    """
    type_assertion = _make_aif_resource(g, type_assertion_uri, RDF.Statement, system)
    g.add((type_assertion, RDF.subject, entity_or_event))
    g.add((type_assertion, RDF.predicate, RDF.type))
    g.add((type_assertion, RDF['object'], _type))
    mark_confidence(g, type_assertion, confidence, system)
    return type_assertion


def mark_justification(g, things_to_justify, justification):
    """
    Mark something as being justified by a particular justification.

    :param rdflib.graph.Graph g: The underlying RDF model
    :param list things_to_justify: The resource to be marked by the specified justification
    :param rdflib.term.BNode justification: The justification to be marked onto the
        specified resource
    """
    if isinstance(things_to_justify, URIRef):
        things_to_justify = [things_to_justify]

    for thing in things_to_justify:
        g.add((thing, interchange_ontology.justifiedBy, justification))


def make_text_justification(g, doc_id, start_offset, end_offset_inclusive,
                            system, confidence, uri_ref=None):
    """
    Create a justification from a particular snippet of text.

    :param rdflib.graph.Graph g: The underlying RDF model
    :param str doc_id: A string containing the document element (child) ID of the source
        of the justification
    :param int start_offset: An integer offset within the document for the start of
        the justification
    :param int end_offset_inclusive: An integer offset within the document for the end of
        the justification
    :param rdflib.term.URIRef system: The system object for the system which made this
        justification
    :param float confidence: The confidence with which to mark the justification
    :param str uri_ref: A string URI representation of the justification (Default is None)
    """
    if start_offset > end_offset_inclusive:
        raise RuntimeError('start_offset cannot be larger than end_offset_inclusive')
    if start_offset < 0:
        raise RuntimeError('start_offset must be a non-negative number')
    justification = _make_aif_justification(
        g, doc_id, interchange_ontology.TextJustification, system, confidence,
        uri_ref)
    g.add((justification, interchange_ontology.startOffset,
           Literal(start_offset, datatype=XSD.int)))
    g.add((justification, interchange_ontology.endOffsetInclusive,
           Literal(end_offset_inclusive, datatype=XSD.int)))
    return justification


def mark_text_justification(g, things_to_justify, doc_id, start_offset,
                            end_offset_inclusive, system, confidence,
                            uri_ref=None):
    """
    Mark multiple things as being justified by a particular snippet of text.

    :param rdflib.graph.Graph g: The underlying RDF model
    :param list things_to_justify: A list of resources to be marked by the specified text
        document
    :param str doc_id: A string containing the document element (child) ID of the source of
        the justification
    :param int start_offset: An integer offset within the document for the start of
        the justification
    :param int end_offset_inclusive: An integer offset within the document for the end of
        the justification
    :param rdflib.term.URIRef system: The system object for the system which made this
        justification
    :param float confidence: The confidence with which to mark the justification
    :param str uri_ref: A string URI representation of the justification (Default is None)
    """
    justification = make_text_justification(
        g, doc_id, start_offset, end_offset_inclusive, system, confidence,
        uri_ref)
    mark_justification(g, things_to_justify, justification)

    return justification


def mark_confidence(g, to_mark_on, confidence, system):
    """
    Mark a confidence value on a resource.

    :param rdflib.graph.Graph g: The underlying RDF model
    :param to_mark_on: The resource to mark with the specified confidence
    :param float confidence: The confidence with which to mark the resource
    :param rdflib.term.URIRef system: The system object for the system which marked this
        confidence
    """
    confidence_blank_node = _make_aif_resource(g, None, interchange_ontology.Confidence, system)
    g.add((confidence_blank_node, interchange_ontology.confidenceValue,
           Literal(confidence, datatype=XSD.double)))
    g.add((to_mark_on, interchange_ontology.confidence, confidence_blank_node))


def make_relation(g, relation_uri, system):
    """
    Create a relation.

    :param rdflib.graph.Graph g: The underlying RDF model
    :param str relation_uri: A unique string URI for the relation
    :param rdflib.term.URIRef system: The system object for the system which created the
        specified relation
    :returns: The relation object
    :rtype: rdflib.term.URIRef
    """
    return _make_aif_resource(g, relation_uri, interchange_ontology.Relation, system)


def make_relation_in_event_form(g, relation_uri, relation_type, subject_role, subject_resource, object_role,
                                object_resource, type_assertion_uri, system, confidence):
    """
    Make a relation of type [relation_type] between [subject_resource] and [object_resource]
    in a form similar to that of an event: subjects and objects are explicitly linked to
    relation via [subject_role] and [object_role], respectively.

    If [confidence] is not None the relation is marked with the given [confidence]

    :param rdflib.graph.Graph g: The underlying RDF model
    :param str relation_uri: A unique string URI for the specified relation
    :param rdflib.term.URIRef relation_type: The type of relation to make
    :param rdflib.term.URIRef subject_role: The role to link the specified subject to
        the specified relation
    :param rdflib.term.URIRef subject_resource: The subject to which to link the specified
        relation via the specified role
    :param rdflib.term.URIRef object_role: The role to link the specified object to
        the specified relation
    :param rdflib.term.URIRef object_resource: The object to which to link the specified
        relation via the specified role
    :param str type_assertion_uri: The string URI of a type assertion resource with which
        to mark the relation
    :param rdflib.term.URIRef system: The system object for the system which created
        the specified relation
    :param float confidence: If not None, the confidence with which to mark the specified
        relation
    :returns: The created relation resource
    :rtype: rdflib.term.URIRef
    """
    relation = make_relation(g, relation_uri, system)
    mark_type(g, type_assertion_uri, relation, relation_type, system, confidence)
    mark_as_argument(g, relation, subject_role, subject_resource, system, confidence)
    mark_as_argument(g, relation, object_role, object_resource, system, confidence)
    return relation


def mark_as_argument(g, event_or_relation, argument_type, argument_filler, system, confidence, uri=None):
    """
    Mark an entity as filling an argument role for an event or relation. The argument assertion
    will be a blank node.

    :param rdflib.graph.Graph g: The underlying RDF model
    :param rdflib.term.URIRef event_or_relation: The event or relation for which to mark
        the specified argument role
    :param rdflib.term.URIRef argument_type: The type (predicate) of the argument
    :param rdflib.term.URIRef argument_filler: The filler (object) of the argument
    :param rdflib.term.URIRef system: The system object for the system which created this
        argument
    :param float confidence: If not None, the confidence with which to mark the specified
        argument
    :param str uri: A unique string URI for the argument (Default is None)
    :returns: The created event or relation argument assertion
    :rtype: rdflib.term.BNode

    """
    arg_assertion = _make_aif_resource(g, uri, RDF.Statement, system)
    g.add((arg_assertion, RDF.subject, event_or_relation))
    g.add((arg_assertion, RDF.predicate, argument_type))
    g.add((arg_assertion, RDF['object'], argument_filler))
    if confidence is not None:
        mark_confidence(g, arg_assertion, confidence, system)
    return arg_assertion


def make_event(g, event_uri, system):
    """
    Create an event

    :param rdflib.graph.Graph g: The underlying RDF model
    :param str event_uri: A unique string URI for the event
    :param rdflib.term.URIRef system: The system object for the system which created
        this event
    :returns: The created event resource
    :rtype: rdflib.term.URIRef
    """
    return _make_aif_resource(g, event_uri, interchange_ontology.Event, system)


def mark_boundingbox(g, to_mark_on, boundingbox):
    """
    Mark the specified resource with the specified bounding box.

    :param rdflib.graph.Graph g: The underlying RDF model
    :param rdflib.term.BNode to_mark_on: The resource to mark with the specified bounding
        box
    :param Bounding_Box boundingbox: A rectangular box
        within the image that bounds the justification
    """
    bounding_box_resource = BNode()
    g.add((bounding_box_resource, RDF.type, interchange_ontology.BoundingBox))
    g.add((bounding_box_resource, interchange_ontology.boundingBoxUpperLeftX,
           Literal(boundingbox.upper_left[0], datatype=XSD.int)))
    g.add((bounding_box_resource, interchange_ontology.boundingBoxUpperLeftY,
           Literal(boundingbox.upper_left[1], datatype=XSD.int)))
    g.add((bounding_box_resource, interchange_ontology.boundingBoxLowerRightX,
           Literal(boundingbox.lower_right[0], datatype=XSD.int)))
    g.add((bounding_box_resource, interchange_ontology.boundingBoxLowerRightY,
           Literal(boundingbox.lower_right[1], datatype=XSD.int)))

    g.add((to_mark_on, interchange_ontology.boundingBox, bounding_box_resource))

    return bounding_box_resource


def make_image_justification(g, doc_id, boundingbox, system, confidence,
                             uri_ref=None):
    """
    Marks a justification for something appearing in an image.

    :param rdflib.graph.Graph g: The underlying RDF model
    :param str doc_id: A string containing the document element (child) ID of
        the source of the justification
    :param Bounding_Box boundingbox: A rectangular box
        within the image that bounds the justification
    :param rdflib.term.URIRef system: The system object for the system which made
        this justification
    :param float confidence: The confidence with which to mark the justification
    :param str uri_ref: A string URI representation of the image justification
        (Default is None)
    :returns: The created image justification resource
    :rtype: rdflib.term.BNode
    """
    justification = _make_aif_justification(
        g, doc_id, interchange_ontology.ImageJustification, system, confidence,
        uri_ref)
    mark_boundingbox(g, justification, boundingbox)
    return justification


def mark_image_justification(g, things_to_justify, doc_id, boundingbox, system,
                             confidence, uri_ref=None):
    """
    Mark multiple things as being justified by a particular image.

    :param rdflib.graph.Graph g: The underlying RDF model
    :param list things_to_justify: A list of resources to be marked by the
        specified image document
    :param str doc_id: A string containing the document element (child) ID of
        the source of the justification
    :param Bounding_Box boundingbox: A rectangular box
        within the image that bounds the justification
    :param rdflib.term.URIRef system: The system object for the system which marked
        this justification
    :param float confidence: The confidence with which to mark the justification
    :param str uri_ref: A string URI representation of the image justification
        (Default is None)
    :returns: The created image justification resource
    :rtype: rdflib.term.BNode
    """
    justification = make_image_justification(g, doc_id, boundingbox, system,
                                             confidence, uri_ref)
    mark_justification(g, things_to_justify, justification)

    return justification


def make_audio_justification(g, doc_id, start_timestamp, end_timestamp, system,
                             confidence, uri_ref=None):
    """
    Make an audio justification.

    :param rdflib.graph.Graph g: The underlying RDF model
    :param str doc_id: A string containing the document element (child) ID of
        the source of the justification
    :param float start_timestamp: A timestamp within the audio document where the
        justification starts
    :param float end_timestamp: A timestamp within the audio document where the
        justification ends
    :param rdflib.term.URIRef system: The system object for the system which made this
        justification
    :param float confidence: The confidence with which to mark the justification
    :param str uri_ref: (Default is None)
    :returns: The created audio justification resource
    :rtype: rdflib.term.BNode
    """
    if start_timestamp > end_timestamp:
        raise RuntimeError("start_timestamp cannot be larger than end_timestamp")
    justification = _make_aif_justification(
        g, doc_id, interchange_ontology.AudioJustification, system, confidence,
        uri_ref)
    g.add((justification, interchange_ontology.startTimestamp,
           Literal(start_timestamp, datatype=XSD.double)))
    g.add((justification, interchange_ontology.endTimestamp,
           Literal(end_timestamp, datatype=XSD.double)))

    return justification


def mark_audio_justification(g, things_to_justify, doc_id, start_timestamp,
                             end_timestamp, system, confidence, uri_ref=None):
    """
    Mark multiple things as being justified by appearing in an audio document.

    :param rdflib.graph.Graph g: The underlying RDF model
    :param list things_to_justify: A list of resources to be marked by the
        specified audio document
    :param str doc_id: A string containing the document element (child) ID of
        the source of the justification
    :param float start_timestamp: A timestamp within the audio document where the
        justification starts
    :param float end_timestamp: A timestamp within the audio document where the
        justification ends
    :param rdflib.term.URIRef system: The system object for the system which marked
        this justification
    :param float confidence: The confidence with which to mark the justification
    :param str uri_ref: A string URI representation of the audio justification
        (Default is None)
    :returns: The created audio justification resource
    :rtype: rdflib.term.BNode
    """
    justification = make_audio_justification(
        g, doc_id, start_timestamp, end_timestamp, system, confidence, uri_ref)
    mark_justification(g, things_to_justify, justification)

    return justification


def make_video_justification(g, doc_id, start_timestamp, end_timestamp, channel,
                             system, confidence, uri_ref=None):
    """
    Make a video justification.

    :param rdflib.graph.Graph g: The underlying RDF model
    :param str doc_id: A string containing the document element (child) ID of
        the source of the justification
    :param float start_timestamp: A timestamp within the video document where the
        justification starts
    :param float end_timestamp: A timestamp within the video document where the
        justification ends
    :param rdflib.term.URIRef channel: The channel of the video that the mention
        appears in. See: InterchangeOntology.VideoJustificationChannel
    :param rdflib.term.URIRef system: The system object for the system which made this
        justification
    :param float confidence: The confidence with which to mark the justification
    :param str uri_ref: (Default is None)
    :returns: The created video justification resource
    :rtype: rdflib.term.BNode
    """
    if start_timestamp > end_timestamp:
        raise RuntimeError("start_timestamp cannot be larger than end_timestamp")
    justification = _make_aif_justification(
        g, doc_id, interchange_ontology.VideoJustification, system, confidence,
        uri_ref)
    g.add((justification, interchange_ontology.startTimestamp,
           Literal(start_timestamp, datatype=XSD.double)))
    g.add((justification, interchange_ontology.endTimestamp,
           Literal(end_timestamp, datatype=XSD.double)))
    g.add((justification, interchange_ontology.channel, channel))

    return justification

def make_keyframe_video_justification(g, doc_id, key_frame, boundingbox, system, confidence, uri_ref=None):
    """
    Create a justification from something appearing in a key frame of a video.

    :param rdflib.graph.Graph g: The underlying RDF model
    :param str doc_id: A string containing the document element (child) ID of
        the source of the justification
    :param str key_frame: The string Id of the key frame of the specified video document
    :param Bounding_Box boundingbox: A rectangular box within
        the key frame that bounds the justification
    :param rdflib.term.URIRef system: The system object for the system which marked
        this justification
    :param float confidence: The confidence with which to mark the justification
    :param str uri_ref: A string URI representation of the video justification (Default is None)
    :returns: The created video justification resource
    :rtype: rdflib.term.BNode
    """
    justification = _make_aif_justification(
        g, doc_id, interchange_ontology.KeyFrameVideoJustification, system,
        confidence, uri_ref)
    g.add((justification, interchange_ontology.keyFrame,
           Literal(key_frame, datatype=XSD.string)))
    mark_boundingbox(g, justification, boundingbox)

    return justification


def mark_keyframe_video_justification(g, things_to_justify, doc_id, key_frame, boundingbox, system, confidence, uri_ref=None):
    """
    Mark multiple things as being justified by appearing in a key frame of a video.

    :param rdflib.graph.Graph g: The underlying RDF model
    :param list things_to_justify: A list of resources to be marked by the specified
        video document
    :param str doc_id: A string containing the document element (child) ID of
        the source of the justification
    :param str key_frame: The string Id of the key frame of the specified video document
    :param Bounding_Box boundingbox: A rectangular box within
        the key frame that bounds the justification
    :param rdflib.term.URIRef system: The system object for the system which marked
        this justification
    :param float confidence: The confidence with which to mark the justification
    :param str uri_ref: A string URI representation of the video justification (Default is None)
    :returns: The created video justification resource
    :rtype: rdflib.term.BNode
    """
    justification = make_keyframe_video_justification(g, doc_id, key_frame, boundingbox, system, confidence, uri_ref)
    mark_justification(g, things_to_justify, justification)

    return justification


def make_shot_video_justification(g, doc_id, shot_id, system, confidence,
                                  uri_ref=None):
    """
    Create a justification from something appearing in a video but not in a key frame.

    :param rdflib.graph.Graph g: The underlying RDF model
    :param str doc_id: A string containing the document element (child) ID of the
        source of the justification
    :param str shot_id: The string Id of the shot of the specified video document
    :param rdflib.term.URIRef system: The system object for the system which made
        this justification
    :param float confidence: The confidence with which to mark the justification
    :param str uri_ref: A string URI representation of the video justification (Default is None)
    :returns: The created video justification resource
    :rtype: rdflib.term.BNode
    """
    justification = _make_aif_justification(
        g, doc_id, interchange_ontology.ShotVideoJustification, system, confidence,
        uri_ref)
    g.add((justification, interchange_ontology.shot,
           Literal(shot_id, datatype=XSD.string)))

    return justification


def mark_shot_video_justification(g, things_to_justify, doc_id, shot_id, system,
                                  confidence, uri_ref=None):
    """
    Mark multiple things as being justified by appearing in a video but not in a key frame

    :param rdflib.graph.Graph g: The underlying RDF model
    :param list things_to_justify: A list of resources to be marked by the specified
        video document
    :param str shot_id: The string Id of the shot of the specified video document
    :param str doc_id: A string containing the document element (child) ID of the
        source of the justification
    :param rdflib.term.URIRef system: The system object for the system which made
        this justification
    :param float confidence: The confidence with which to mark the justification
    :param str uri_ref: A string URI representation of the video justification (Default is None)
    :returns: The created video justification resource
    :rtype: rdflib.term.BNode
    """
    justification = make_shot_video_justification(g, doc_id, shot_id, system,
                                                  confidence, uri_ref)
    mark_justification(g, things_to_justify, justification)

    return justification


def mark_compound_justification(g, things_to_justify, justifications, system, confidence):
    """
    Combine justifications into single justifiedBy triple with new confidence.

    :param rdflib.graph.Graph g: The underlying RDF model
    :param list things_to_justify: A list of resources to be marked by the specified justifications
    :param list justifications: A list of resources that justify the resources to be marked
    :param rdflib.term.URIRef system: The system object for the system which made these justifications
    :param float confidence: The confidence with which to mark each justification
    :returns: The created compound justification resource
    :rtype: rdflib.term.BNode
    """
    compound_justification = _make_aif_resource(g, None, interchange_ontology.CompoundJustification, system)
    mark_confidence(g, compound_justification, confidence, system)
    for justification in justifications:
        g.add((compound_justification, interchange_ontology.containedJustification, justification))
    mark_justification(g, things_to_justify, compound_justification)
    return compound_justification


def add_source_document_to_justification(g, justification, source_document):
    """
    Add a sourceDocument to a pre-existing justification

    :param rdflib.graph.Graph g: The underlying RDF model
    :param rdflib.term.BNode justification: A pre-existing justification resource
    :param str source_document: A string containing the source document (parent) ID
    :returns: The modified justification
    :rtype: rdflib.term.BNode
    """
    g.add((justification, interchange_ontology.sourceDocument,
            Literal(source_document, datatype=XSD.string)))
    return justification

def mark_handle(g, to_mark, handle) -> URIRef:
    """
    Add a handle to an existing resource

    :param rdflib.graph.Graph g: The underlying RDF model
    :param rdflib.term.URIRef to_mark: Reference to mark with a handle
    :param str handle: A string containing the handle
    :returns: The marked reference
    :rtype: rdflib.term.URIRef
    """
    if handle is not None:
        g.add((to_mark, interchange_ontology.handle, Literal(handle, datatype=XSD.string)))
    return to_mark

def make_cluster_with_prototype(g, cluster_uri, prototype, system, handle=None):
    """
    Create a "same-as" cluster.

    A same-as cluster is used to represent multiple entities which might be the same, but we
    aren't sure. (If we were sure, they would just be a single node).

    Every cluster requires a [prototype] - an entity or event that we are *certain* is in the
    cluster.

    :param rdflib.graph.Graph g: The underlying RDF model
    :param str cluster_uri: A unique String URI for the cluster
    :param rdflib.term.URIRef prototype: an entity, event, or relation that we are certain is in the cluster
    :param system: The system object for the system which created the specified cluster
    :param str handle: A string describing the cluster (Default is None)
    :returns: The cluster created
    :rtype: rdflib.term.URIRef
    """
    cluster = _make_aif_resource(g, cluster_uri, interchange_ontology.SameAsCluster, system)
    g.add((cluster, interchange_ontology.prototype, prototype))
    return mark_handle(g, cluster, handle)


def mark_as_possible_cluster_member(g, possible_cluster_member, cluster, confidence, system, uri_ref=None):
    """
    Mark an entity or event as a possible member of a cluster.

    :param rdflib.graph.Graph g: The underlying RDF model
    :param rdflib.term.URIRef possible_cluster_member: The entity or event to mark as a possible
        member of the specified cluster
    :param rdflib.term.URIRef cluster: The cluster to associate with the possible cluster member
    :param float confidence: The confidence with which to mark the cluster membership
    :param rdflib.term.URIRef system: The system object for the system which marked the specified cluster
    :param str uri_ref: A string URI representation of the cluster member (Default is None)
    :returns: The cluster membership assertion
    :rtype: rdflib.term.BNode
    """
    cluster_member_assertion = _make_aif_resource(g, uri_ref, interchange_ontology.ClusterMembership, system)
    g.add((cluster_member_assertion, interchange_ontology.cluster, cluster))
    g.add((cluster_member_assertion, interchange_ontology.clusterMember, possible_cluster_member))
    mark_confidence(g, cluster_member_assertion, confidence, system)
    return cluster_member_assertion


def make_hypothesis(g, hypothesis_uri, hypothesis_content, system):
    """
    Create a hypothesis

    You can then indicate that some other object depends on this hypothesis using mark_depends_on_hypothesis

    :param rdflib.graph.Graph g: The underlying RDF model
    :param str hypothesis_uri: A unique String URI for the hypothesis
    :param list hypothesis_content: A list of entities, relations, and arguments that contribute
        to the hypothesis
    :param rdflib.term.URIRef system: The system object for the system which made the hypothesis
    :return: The hypothesis resource
    :rtype: rdflib.term.URIRef
    """
    if not hypothesis_content:
        raise RuntimeError("hypothesis_content cannot be empty")

    hypothesis = _make_aif_resource(g, hypothesis_uri, interchange_ontology.Hypothesis, system)

    subgraph = BNode()
    g.add((subgraph, RDF.type, interchange_ontology.Subgraph))

    for content in hypothesis_content:
        g.add((subgraph, interchange_ontology.subgraphContains, content))

    g.add((hypothesis, interchange_ontology.hypothesisContent, subgraph))
    return hypothesis


def mark_importance(g, resource, importance):
    """
    Mark [resource] as having the specified [importance] value.

    :param rdflib.graph.Graph g: The underlying RDF model
    :param rdflib.term.URIRef resource: The resource to mark with the specified importance
    :param float importance: The importance value with which to mark the specified Resource
    """
    g.add((resource, interchange_ontology.importance, Literal(importance, datatype=XSD.double)))


def mark_informative_justification(g, resource, informative_justification):
    """
    Mark resource as having an informativeJustification value

    :param rdflib.graph.Graph g: The underlying RDF model
    :param resource: the resource to mark with the specified importance
    :param informative_justification: the justification which will be considered informative
    """
    g.add((resource, interchange_ontology.informativeJustification, informative_justification))


def mark_depends_on_hypothesis(g, depender, hypothesis):
    """
    Mark an argument as depending on a hypothesis.

    :param rdflib.graph.Graph g: The underlying RDF model
    :param rdflib.term.URIRef depender: the argument that depends on the specified hypothesis
    :param rdflib.term.URIRef hypothesis: The hypothesis upon which to depend
    """
    g.add((depender, interchange_ontology.dependsOnHypothesis, hypothesis))


def mark_as_mutually_exclusive(g, alternatives, system, none_of_the_above_prob):
    """
    Mark the given resources as mutually exclusive.

    This is a special case of [mark_as_mutually_exclusive] where the alternatives are
    each single edges, so we simply wrap each edge in a collection and pass to
    mark_as_mutually_exclusive.

    :param rdflib.graph.Graph g: The underlying RDF model
    :param dict alternatives: a dictionary of edges which form a sub-graph for
        an alternative to the confidence associated with an alternative.
    :param rdflib.term.URIRef system: The system object for the system which contains the
        mutual exclusion
    :param float none_of_the_above_prob: if not None, the given confidence will be applied for
        the "none of the above" option.
    :returns: The created mutual exclusion assertion resource
    :rtype: rdflib.term.BNode
    """
    if len(alternatives) < 2:
        raise RuntimeError("alternatives cannot have less than 2 mutually exclusive things")

    mutual_exclusion_assertion = _make_aif_resource(g, None, interchange_ontology.MutualExclusion, system)

    for (edges_for_alternative, confidence) in alternatives.items():
        alternative = BNode()
        g.add((alternative, RDF.type, interchange_ontology.MutualExclusionAlternative))

        alternative_graph = BNode()
        g.add((alternative_graph, RDF.type, interchange_ontology.Subgraph))
        for alt in edges_for_alternative:
            g.add((alternative_graph, interchange_ontology.subgraphContains, alt))

        g.add((alternative, interchange_ontology.alternativeGraph, alternative_graph))
        mark_confidence(g, alternative, confidence, system)

        g.add((mutual_exclusion_assertion, interchange_ontology.alternative, alternative))

    if none_of_the_above_prob is not None:
        g.add((mutual_exclusion_assertion, interchange_ontology.noneOfTheAbove,
               Literal(none_of_the_above_prob, datatype=XSD.double)))

    return mutual_exclusion_assertion


def mark_private_data(g, resource, json_content, system):
    """
    Mark data as private from JSON data. Private data should not contain document-level content features.
    Allowable private data include:

    - fringe type(s) for the KE
    - a vectorized representation of the KE, which cannot grow as the number of mentions/justifications for the KE
      increases, and from which a raw document (or significant portions thereof) cannot be recoverable
    - the number of documents that justify the KE
    - time stamps of justification documents
    - fringe type(s) for each image or shot, to describe features that are not represented explicitly in the
      ontology.  For example: Physical.LocatedNear.Inside(Arg1_Type=Person.Soldier, Arg2_Type=Facility.Hospital)

    The KE is not allowed to contain any strings from document text except for the strings in the HasName,
    NumericValue, and TextValue properties

    :param rdflib.graph.Graph g: The underlying RDF model
    :param rdflib.term.URIRef resource: The entity with which to associate private data
    :param str json_content: Valid JSON content (in key/value pairs) that represents the private data
    :param rdflib.term.URIRef system: The system object for the system which marks the private data
    :returns: The created private data resource
    :rtype: rdflib.term.BNode
    """
    private_data = _make_aif_resource(g, None, interchange_ontology.PrivateData, system)
    g.add((private_data, interchange_ontology.jsonContent,
           Literal(json_content, datatype=XSD.string)))

    g.add((resource, interchange_ontology.privateData, private_data))

    return private_data


def mark_private_data_with_vector(g, resource, system, vector):
    """
    Mark data as private from vector data. Private data should not contain document-level content features.
    Allowable private data include:

    - fringe type(s) for the KE
    - a vectorized representation of the KE, which cannot grow as the number of mentions/justifications for the KE
      increases, and from which a raw document (or significant portions thereof) cannot be recoverable
    - the number of documents that justify the KE
    - time stamps of justification documents
    - fringe type(s) for each image or shot, to describe features that are not represented explicitly in the
      ontology.  For example: Physical.LocatedNear.Inside(Arg1_Type=Person.Soldier, Arg2_Type=Facility.Hospital)

    The KE is not allowed to contain any strings from document text except for the strings in the HasName,
    NumericValue, and TextValue properties

    :param rdflib.graph.Graph g: The underlying RDF model
    :param rdflib.term.URIRef resource: The entity with which to associate private data
    :param str vector: A string of numeric data that represents the private data
    :param rdflib.term.URIRef system: The system object for the system which marks the private data
    :returns: The created private data resource
    :rtype: rdflib.term.BNode
    :raises RuntimeError: if vector is None
    """
    if vector is None:
        raise RuntimeError("vector cannot be null")

    vector = json.dumps(vector)
    private_data = mark_private_data(g, resource, str(vector), system)
    return private_data


def link_to_external_kb(g, to_link, external_kb_id, system, confidence,
                        uri_ref=None):
    """
    Link an entity to something in an external KB.

    :param rdflib.graph.Graph g: The underlying RDF model
    :param rdflib.term.URIRef to_link: The entity to which to link
    :param str external_kb_id: A unique String URI of the external KB
    :param rdflib.term.URIRef system: The system object for the system which make the link
    :param float confidence: If not None, the confidence with which to mark the linkage
    :param str uri_ref: A string URI representation of the link (Default is None)
    :returns: The created link assertion resource
    :rtype: rdflib.term.BNode
    """
    if uri_ref is None:
        link_assertion = BNode()
    else:
        link_assertion = URIRef(uri_ref)
    g.add((to_link, interchange_ontology.link, link_assertion))
    g.add((link_assertion, RDF.type, interchange_ontology.LinkAssertion))
    g.add((link_assertion, interchange_ontology.linkTarget,
           Literal(external_kb_id, datatype=XSD.string)))
    mark_system(g, link_assertion, system)
    mark_confidence(g, link_assertion, confidence, system)
    return link_assertion


def _make_aif_resource(g, uri, class_type, system):
    """
    Helper function to create an event, relation, justification, etc. in the system.

    :param rdflib.graph.Graph g: The underlying RDF model
    :param str uri: The string URI of the resource
    :param rdflib.term.URIRef class_type: The class type of the resource
    :param rdflib.term.URIRef system: The system object for the system which marks the resource
    :returns: The created AIF resource
    :rtype: rdflib.term.BNode
    """
    if uri is None:
        resource = BNode()
    else:
        resource = URIRef(uri)
    g.add((resource, RDF.type, class_type))
    if system is not None:
        mark_system(g, resource, system)
    return resource


def _make_aif_justification(g, doc_id, class_type, system, confidence,
                            uri_ref=None):
    """
    Helper function to create a justification (text, image, audio, etc.) in the system.

    :param rdflib.graph.Graph g: The underlying RDF model
    :param str doc_id: A string containing the document element (child) ID of the source
        of the justification
    :param rdflib.term.URIRef class_type: The class type of the resource
    :param rdflib.term.URIRef system: The system object for the system which marks the
        justification
    :param float confidence: If not None, the confidence with which to mark the linkage
    :param str uri_ref: A string URI representation of the justification (Default is None)
    :returns: The created justification
    :rtype: rdflib.term.BNode
    """
    justification = _make_aif_resource(g, uri_ref, class_type, system)
    g.add((justification, interchange_ontology.source,
           Literal(doc_id, datatype=XSD.string)))
    mark_confidence(g, justification, confidence, system)
    return justification


_TYPE_QUERY = prepareQuery("""SELECT ?typeAssertion WHERE {
  ?typeAssertion a rdf:Statement .
  ?typeAssertion rdf:predicate rdf:type .
  ?typeAssertion rdf:subject ?typedObject .
  }
  """)


def get_type_assertions(g, typed_object):
    """
    Retrieve all type assertions from an entity.

    :param rdflib.graph.Graph g: The underlying RDF model
    :param rdflib.term.URIRef typed_object: The entity from which to retrieve
        type assertions
    :returns: A list of type assertions for the specified entity
    :rtype: list
    """
    query_result = g.query(_TYPE_QUERY, initBindings={'typedObject': typed_object})
    return [x for (x,) in query_result]


def get_confidences(g, confidenced_object):
    """
    Retrieve all confidence assertions from an entity.

    This does not get confidences attached to sub-graphs containing the object.

    :param rdflib.graph.Graph g: The underlying RDF model
    :param rdflib.term.URIRef confidenced_object: The entity from which to retrieve
        confidence assertions
    :returns: A list of confidence assertions describing this object.
    :rtype: list
    """
    return list(g.objects(confidenced_object, interchange_ontology.confidence))


def mark_ldc_time(g, to_mark, start, end, system):
    """
    Add LDC start and end time representation to an Event or Relation

    :param rdflib.graph.Graph g: The underlying RDF model
    :param rdflib.term.URIRef to_mark: The Event or Relation to add the LDC time data to
    :param LDCTimeComponent start: containing the start time information
    :param LDCTimeComponent end: containing the end time information
    :param rdflib.term.URIRef  system: The system object for the system which marks the time
    :returns: The LDCTimeComponent resource
    :rtype: rdflib.term.BNode
    """
    ldc_time = _make_aif_resource(g, None, interchange_ontology.LDCTime, system)
    if start:
        g.add((ldc_time, interchange_ontology.start, start.make_aif_time_component(g)))
    if end:
        g.add((ldc_time, interchange_ontology.end, end.make_aif_time_component(g)))

    g.add((to_mark, interchange_ontology.ldcTime, ldc_time))

    return ldc_time

def mark_ldc_time_range(g, to_mark, startEarliest, startLatest, endEarliest, endLatest, system):
    """
    Add LDC start and end time representation to an Event or Relation

    :param rdflib.graph.Graph g: The underlying RDF model
    :param rdflib.term.URIRef to_mark: The Event or Relation to add the LDC time data to
    :param LDCTimeComponent startEarliest: containing the earliest start time information
    :param LDCTimeComponent startLatest: containing the latest start time information
    :param LDCTimeComponent endEarliest: containing the earliest end time information
    :param LDCTimeComponent endLatest: containing the latest end time information
    :param rdflib.term.URIRef  system: The system object for the system which marks the time
    :returns: The LDCTimeComponent resource
    :rtype: rdflib.term.BNode
    """
    ldc_time = _make_aif_resource(g, None, interchange_ontology.LDCTime, system)
    if startEarliest:
        g.add((ldc_time, interchange_ontology.start, startEarliest.make_aif_time_component(g)))
    if startLatest:
        g.add((ldc_time, interchange_ontology.start, startLatest.make_aif_time_component(g)))
    if endEarliest:
        g.add((ldc_time, interchange_ontology.end, endEarliest.make_aif_time_component(g)))
    if endLatest:
        g.add((ldc_time, interchange_ontology.end, endLatest.make_aif_time_component(g)))

    g.add((to_mark, interchange_ontology.ldcTime, ldc_time))

    return ldc_time



class Bounding_Box:
    """
    Object that represents image/video coordinates
    """

    def __init__(self, upper_left, lower_right):
        self.upper_left = upper_left
        self.lower_right = lower_right
        


from rdflib import URIRef

# WARNING. This is a Generated File. Please do not edit.
# Please refer to the README at java/src/main/java/com/ncc/aif/ont2javagen for more information
# Last generated on: 08/24/2020 11:09:20
NAMESPACE = 'https://raw.githubusercontent.com/NextCenturyCorporation/AIDA-Interchange-Format/master/java/src/main/resources/com/ncc/aif/ontologies/InterchangeOntology#'

# Classes
AudioJustification = URIRef(NAMESPACE + 'AudioJustification')
BoundingBox = URIRef(NAMESPACE + 'BoundingBox')
ClusterMembership = URIRef(NAMESPACE + 'ClusterMembership')
CompoundJustification = URIRef(NAMESPACE + 'CompoundJustification')
Confidence = URIRef(NAMESPACE + 'Confidence')
Entity = URIRef(NAMESPACE + 'Entity')
Event = URIRef(NAMESPACE + 'Event')
Hypothesis = URIRef(NAMESPACE + 'Hypothesis')
ImageJustification = URIRef(NAMESPACE + 'ImageJustification')
Justification = URIRef(NAMESPACE + 'Justification')
JustificationTypes = URIRef(NAMESPACE + 'JustificationTypes')
KeyFrameVideoJustification = URIRef(NAMESPACE + 'KeyFrameVideoJustification')
LDCTime = URIRef(NAMESPACE + 'LDCTime')
LDCTimeComponent = URIRef(NAMESPACE + 'LDCTimeComponent')
LinkAssertion = URIRef(NAMESPACE + 'LinkAssertion')
MutualExclusion = URIRef(NAMESPACE + 'MutualExclusion')
MutualExclusionAlternative = URIRef(NAMESPACE + 'MutualExclusionAlternative')
PrivateData = URIRef(NAMESPACE + 'PrivateData')
Relation = URIRef(NAMESPACE + 'Relation')
SameAsCluster = URIRef(NAMESPACE + 'SameAsCluster')
ShotVideoJustification = URIRef(NAMESPACE + 'ShotVideoJustification')
Subgraph = URIRef(NAMESPACE + 'Subgraph')
System = URIRef(NAMESPACE + 'System')
TextJustification = URIRef(NAMESPACE + 'TextJustification')
VideoJustification = URIRef(NAMESPACE + 'VideoJustification')
VideoJustificationChannel = URIRef(NAMESPACE + 'VideoJustificationChannel')

# Individuals
VideoJustificationChannelBoth = URIRef(NAMESPACE + 'VideoJustificationChannelBoth')
VideoJustificationChannelPicture = URIRef(NAMESPACE + 'VideoJustificationChannelPicture')
VideoJustificationChannelSound = URIRef(NAMESPACE + 'VideoJustificationChannelSound')

# Properties
alternative = URIRef(NAMESPACE + 'alternative')
alternativeGraph = URIRef(NAMESPACE + 'alternativeGraph')
boundingBox = URIRef(NAMESPACE + 'boundingBox')
boundingBoxLowerRightX = URIRef(NAMESPACE + 'boundingBoxLowerRightX')
boundingBoxLowerRightY = URIRef(NAMESPACE + 'boundingBoxLowerRightY')
boundingBoxUpperLeftX = URIRef(NAMESPACE + 'boundingBoxUpperLeftX')
boundingBoxUpperLeftY = URIRef(NAMESPACE + 'boundingBoxUpperLeftY')
channel = URIRef(NAMESPACE + 'channel')
cluster = URIRef(NAMESPACE + 'cluster')
clusterMember = URIRef(NAMESPACE + 'clusterMember')
confidence = URIRef(NAMESPACE + 'confidence')
confidenceValue = URIRef(NAMESPACE + 'confidenceValue')
containedJustification = URIRef(NAMESPACE + 'containedJustification')
day = URIRef(NAMESPACE + 'day')
dependsOnHypothesis = URIRef(NAMESPACE + 'dependsOnHypothesis')
end = URIRef(NAMESPACE + 'end')
endOffsetInclusive = URIRef(NAMESPACE + 'endOffsetInclusive')
endTimestamp = URIRef(NAMESPACE + 'endTimestamp')
handle = URIRef(NAMESPACE + 'handle')
hasName = URIRef(NAMESPACE + 'hasName')
hypothesisContent = URIRef(NAMESPACE + 'hypothesisContent')
importance = URIRef(NAMESPACE + 'importance')
informativeJustification = URIRef(NAMESPACE + 'informativeJustification')
jsonContent = URIRef(NAMESPACE + 'jsonContent')
justifiedBy = URIRef(NAMESPACE + 'justifiedBy')
keyFrame = URIRef(NAMESPACE + 'keyFrame')
ldcTime = URIRef(NAMESPACE + 'ldcTime')
link = URIRef(NAMESPACE + 'link')
linkTarget = URIRef(NAMESPACE + 'linkTarget')
month = URIRef(NAMESPACE + 'month')
noneOfTheAbove = URIRef(NAMESPACE + 'noneOfTheAbove')
numericValue = URIRef(NAMESPACE + 'numericValue')
privateData = URIRef(NAMESPACE + 'privateData')
prototype = URIRef(NAMESPACE + 'prototype')
shot = URIRef(NAMESPACE + 'shot')
source = URIRef(NAMESPACE + 'source')
sourceDocument = URIRef(NAMESPACE + 'sourceDocument')
start = URIRef(NAMESPACE + 'start')
startOffset = URIRef(NAMESPACE + 'startOffset')
startTimestamp = URIRef(NAMESPACE + 'startTimestamp')
subgraphContains = URIRef(NAMESPACE + 'subgraphContains')
system = URIRef(NAMESPACE + 'system')
textValue = URIRef(NAMESPACE + 'textValue')
timeType = URIRef(NAMESPACE + 'timeType')
year = URIRef(NAMESPACE + 'year')



from rdflib import URIRef

# WARNING. This is a Generated File. Please do not edit.
# Please refer to the README at java/src/main/java/com/ncc/aif/ont2javagen for more information
# Last generated on: 08/24/2020 11:09:20
NAMESPACE = 'https://raw.githubusercontent.com/NextCenturyCorporation/AIDA-Interchange-Format/master/java/src/main/resources/com/ncc/aif/ontologies/AidaDomainOntologiesCommon#'

# Classes
CanHaveName = URIRef(NAMESPACE + 'CanHaveName')
CanHaveNumericValue = URIRef(NAMESPACE + 'CanHaveNumericValue')
CanHaveTextValue = URIRef(NAMESPACE + 'CanHaveTextValue')
EntityType = URIRef(NAMESPACE + 'EntityType')
EventArgumentType = URIRef(NAMESPACE + 'EventArgumentType')
EventType = URIRef(NAMESPACE + 'EventType')
RelationArgumentType = URIRef(NAMESPACE + 'RelationArgumentType')
RelationType = URIRef(NAMESPACE + 'RelationType')



from enum import Enum

from rdflib import XSD, Literal, URIRef

from aida_interchange import aifutils
from aida_interchange.rdf_ontologies import interchange_ontology


class LDCTimeType(Enum):
    """
    Enumeration of time types
    """
    ON = 1
    BEFORE = 2
    AFTER = 3
    UNKNOWN = 4

class LDCTimeComponent:
    """
    This class encapsulates the LDC representation of time
    """

    def __init__(self, time_type, year, month, day):
        self.time_type = time_type
        self.year = year
        self.month = month
        self.day = day


    def add_literal(self, g, time_component, time_property, value, literal_type):
        """
        Creates and adds a Literal to the model if a value exists

        :param LDCTimeComponent self: contains the time component information when LDCTimeComponent is instantiated
        :param rdflib.graph.Graph g: The underlying RDF model for the operation
        :param rdflib.term.BNode time_component: The resource created to contain time information
        :param time_property: AIDA_ANNOTATION.year, AIDA_ANNOTATION.month, or AIDA_ANNOTATION.day
        :param str value: the string value of month, day, or year
        :param literal_type: the datatype that corresponds to the given value
        """
        if value is not None:
            temp_literal = Literal(value)
            temp_literal._datatype = URIRef(literal_type)
            g.add((time_component, time_property, temp_literal))


    def make_aif_time_component(self, g):
        """
        Creates a time component containing a Year, Month, and Day as well as a Type to clarify relative time
        
        :param LDCTimeComponent self: contains the time component information when LDCTimeComponent is instantiated
        :param rdflib.graph.Graph g: The underlying RDF model for the operation
        :returns: time_component node
        """
        time_component = aifutils._make_aif_resource(g, None, interchange_ontology.LDCTimeComponent, None)
        g.add((time_component, interchange_ontology.timeType, Literal(self.time_type.name, datatype=XSD.string)))
        self.add_literal(g, time_component, interchange_ontology.year, self.year, XSD.gYear)
        self.add_literal(g, time_component, interchange_ontology.month, self.month, XSD.gMonth)
        self.add_literal(g, time_component, interchange_ontology.day, self.day, XSD.gDay)
        return time_component



from setuptools import setup, find_packages

setup(name='aida-interchange',
      version='1.2.1',
      author='Next Century Corporation',
      author_email='aif-support@nextcentury.com',
      description='AIDA Interchange Format',
      long_description=open('README.md').read(),
      long_description_content_type='text/markdown',
      url='https://github.com/NextCenturyCorporation/AIDA-Interchange-Format',
      packages=find_packages(exclude=['tests']),
      python_requires='~=3.0',
      install_requires=[
        'rdflib',
        'sphinx>=2.0.1',
        'attrs>=17.4.0',
        'typing_extensions',
      ],
      classifiers=(
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
      ),
)
